-- declaring local variables that will be used only inside map-functions.lua
local tileW, tileH, tileset, quads, tileTable --- Creates local variables for Map Functions

tileString = [[]] --- Creates the tileString string
TILESIZE = 16 --- Creates the defualt tile size


function loadMap(path)
  love.filesystem.load(path)() -- Used for loading in maps
  return tileString --- Looks for stuff inside maps
 end

function newMap(tileW, tileH, tilesetPath, tileString, quadInfo) --- Builds maps
  
  TileW = tileW
  TileH = tileH
  Tileset = love.graphics.newImage(tilesetPath)
  
  local tilesetW, tilesetH = Tileset:getWidth(), Tileset:getHeight()
  
  Quads = {}
  
  for _,info in ipairs(quadInfo) do
    -- info[1] = the character, info[2] = x, info[3] = y
    Quads[info[1]] = love.graphics.newQuad(info[2], info[3], TileW,  TileH, tilesetW, tilesetH)
  end
  
  TileTable = {}
  
  local width = #(tileString:match("[^\n]+"))

  for x = 1,width,1 do TileTable[x] = {} end

  local x,y = 1,1
  for row in tileString:gmatch("[^\n]+") do --- Looks for multilined string.
    assert(#row == width, 'Map is not aligned: width of row ' .. tostring(y) .. ' should be ' .. tostring(width) .. ', but it is ' .. tostring(#row))
    x = 1
    for tile in row:gmatch(".") do
      TileTable[x][y] = tile
      x = x + 1
    end
    y=y+1
  end

end

function drawMap() --- This builds the map.
    for columnIndex,column in ipairs(TileTable) do
    for rowIndex,char in ipairs(column) do
      local x,y = (columnIndex-1)*TileW, (rowIndex-1)*TileH
      love.graphics.drawq(Tileset, Quads[char], x, y)
    end
  end

end

function testMap(x, y) --- This preforms collisions
    local testX = math.floor(player.grid_x + x + 0.5) --- Preforms something similar to the player function
    local testY = math.floor(player.grid_y + y)

   print('player.grid_y: '..player.grid_y) --- Prints information about player movement, is a bit buggy
   print('player.grid_x: '..player.grid_x)
   print('x: '..x)
   print('y: '..y)
   print('testX: '..testX)
   print('testY: '..testY) --- Finish

   if not TileTable[testX] or --- Checks to see where the players location is.
      not TileTable[testX][testY] then
      print(string.format('TileTable[%s][%s] doesn\'t exist!', testX, testY))
   else
      print('TileTable[testX][testY]: '..TileTable[testX][testY])
   end

   if not TileTable[testX] or
      not TileTable[testX][testY] or
      TileTable[testX][testY] == '-' or
      TileTable[testX][testY] == '#' then
      return false
   end
   return true
end